<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services;

use App\Repositories\Contracts\PlatformCustomerRepository;
use App\Rhawn\Repositories\Contracts\BhuaCustomerRepository;
use App\Rhawn\Repositories\Contracts\RhawnCustomerRepository;
use App\Rhawn\Services\BhuaCustomerService;
use App\Rhawn\Services\RhawnCustomerService;
use App\Support\Facades\SimpleLogs;
use App\Support\Traits\Helpers;
use Illuminate\Support\Facades\DB;

class CustomerService
{
    use Helpers;

    public function __construct(PlatformCustomerRepository $platformCustomerRepository)
    {
        $this->platformCustomerRepository = $platformCustomerRepository;
        $this->rhawnCustomerService = (new RhawnCustomerService(app(RhawnCustomerRepository::class)));
        $this->bhuaCustomerService = (new BhuaCustomerService(app(BhuaCustomerRepository::class)));
    }

    /**
     * 创建api会员信息
     * @param $requestParams
     * @throws \Exception
     */
    public function createPlatformCustomer($requestParams)
    {
        try{
            switch($requestParams['customer_type']){
                case 'rhawn' :
                    $customer = $this->rhawnCustomerService->getRhawnCustomerThroughtCusCode($requestParams['customer_code']);
                    break;
                case 'bh' :
                    $customer = $this->bhuaCustomerService->getBhuaCustomerThroughtCusCode($requestParams['customer_code']);
                    break;
            }
            if(!$customer){
                throw new \Exception('没有找到该客户',500);
            }

            $platformCustomer = $this->platformCustomerRepository->findWhere([
                'cus_id' => $customer['cus_id'],
                'cus_number' => $customer['cus_no']
            ])->toArray();
            if($platformCustomer){
                throw new \Exception('平台用户已存在，无需重复注册',500);
            }

            $newCustomer = [];
            $newCustomer['cus_id'] = $customer['cus_id'];
            $newCustomer['cus_number'] = $customer['cus_no'];
            $newCustomer['company_name'] = $requestParams['customer_company'];
            $newCustomer['token'] = $this->randomFromDevice(16);
            $newCustomer['cus_type'] = $requestParams['customer_type'];
            $newCustomer['platform_params'] = '';
            $newCustomer['status'] = 1;

            $this->platformCustomerRepository->create($newCustomer);

            $platformCustomer = $this->platformCustomerRepository->findWhere(['cus_number' => $customer['cus_no']]);
            return $platformCustomer;

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':createCustomer','error');
            throw $exception;
        }
    }

    /**
     * 获取平台用户信息
     * @param $requestParams
     */
    public function getPlatformCustomer($requestParams)
    {
       $platformCustomer = $this->platformCustomerRepository->find($requestParams['platform_customer_id']);
       if(!$platformCustomer){
           throw new \Exception('平台用户不存在',500);
       }
       return $platformCustomer;
    }

    /**
     * 更新平台用户token
     * @param $requestParams
     * @throws \Throwable
     */
    public function refreshCustomerToken($requestParams)
    {
        try{
            $platformCustomer = $this->platformCustomerRepository->find($requestParams['platform_customer_id']);
            if(!$platformCustomer){
                throw new \Exception('平台用户不存在',500);
            }
            $newToken = $this->randomFromDevice(16);
            $this->platformCustomerRepository->update([
                'token' => $newToken
            ],$platformCustomer['id']);

            return $newToken;

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':refreshCustomerToken','error');
            throw $exception;
        }
    }

    /**
     * 获取用户信息
     * @param $customerCode
     */
    public function getRhawnCustomerInfo($customerCode)
    {
        $customer = $this->rhawnCustomerService->getRhawnCustomerThroughtCusCode($customerCode);
        if($customer){
            return $customer;
        }
        return [];
    }

    /**
     * 根据token获取平台用户信息
     * @param $token
     * @return false|mixed
     * @throws \Throwable
     */
    public function getCustomerInfoByToken($token)
    {
        try{
            $platformCustomer = $this->platformCustomerRepository->findWhere([
                'token' => $token
            ]);
            if(!$platformCustomer){
                throw new \Exception('平台用户不存在',500);
            }
            return current($platformCustomer->toArray());
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':refreshCustomerToken','error');
            throw $exception;
        }
    }

}
